#ifndef __LEDCOMMANDS_H_
#define __LEDCOMMANDS_H_


#include "GenericTypeDefs.h"
#include "Compiler.h"

#define LED_TABLE_LENGTH 10
#define LED_COMMAND_QUE_LENGTH 25

#define LED_TABLE_EEPROM_START_ADDRESS 0xE10

#define ETHERNET_INTERFACE 0
#define MIWI_INTERFACE 1

#define POWER_COMMAND 1
#define SET_RED_COMMAND 2
#define SET_GREEN_COMMAND 3
#define SET_BLUE_COMMAND 4
#define SET_ALL_COMMAND 5
#define CLOSE_COMMAND 7
#define REQUEST_LED_TABLE_COMMAND 10
#define RESET_COMMAND 13
#define REQUEST_POWER_COMMAND 16
#define STORE_LED_COMMAND 21
#define DELETE_LED_COMMAND 22
#define SET_RED_SCALE 32
#define SET_RED_SCALE_CONFIRM 42
#define SET_GREEN_SCALE 33
#define SET_GREEN_SCALE_CONFIRM 43
#define SET_BLUE_SCALE 34
#define SET_BLUE_SCALE_CONFIRM 44

typedef struct _LED_COMMAND {
	BYTE commandcode;
	BYTE param[3];
	BYTE done;
} LED_COMMAND;	

typedef struct _LED_TABLE {
	BYTE address;
	BYTE red;
	BYTE green;
	BYTE blue;
} LED_TABLE;	

#define TempPowerOn() if (!PowerFaultOccurred) VPP_ON=1
#define TempPowerOff() VPP_ON=0

#define isPowerOn() VPP_ON

void SetLEDState(BYTE address, BYTE color, BYTE val);
void SetLEDAddress(BYTE address);
void SetLEDRefVoltage(BYTE address, BYTE PWMValue);
void SetMainPower(BYTE state);
void SendLEDStatus(BYTE interface);
void ProcessLEDCommand(LED_COMMAND *command);
void LoadLEDTable(void);
void ClearLEDTable(void);
void LEDTableTestSetup(void);
void SaveLEDTable(void);
void SaveLEDTableEntry(BYTE EntryIndex);
signed char LEDAddressToIndex(BYTE address);
int BuildLEDTableResponse(BYTE * buffer);
void StoreLEDAddress(BYTE address);
void DeleteLEDAddress(BYTE address);

extern BYTE PowerFaultOccurred;


#endif